@@ -6,7 +6,7 @@ from sqlalchemy import create_engine, exists, select
 from sqlalchemy.orm import sessionmaker, scoped_session, relationship
 from sqlalchemy.orm.collections import InstrumentedList
 from sqlalchemy.ext.declarative import declarative_base, DeclarativeMeta
-from sqlalchemy import Table, Column, Integer, String, Float, ForeignKey, UnicodeText, MetaData, Sequence, DateTime, Date, Time
+from sqlalchemy import Table, Column, Integer, String, Float, ForeignKey, UnicodeText, MetaData, Sequence, DateTime, Date, Time, Interval
 from sqlalchemy import and_, or_
 from sqlalchemy.sql.expression import literal
 
@@ -17,6 +17,9 @@ or_ = or_
 
 UnicodeText = UnicodeText
 DateTime = DateTime
+Date = Date
+Time = Time
+Interval = Interval
 
 Table = Table
 Column = Column
